@@ -4,7 +4,7 @@ use 5.008001;
 use Moose;
 use MooseX::Types::Moose qw( Str Maybe HashRef );
 
-our $VERSION = '1.102';
+our $VERSION = '1.102002';
 $VERSION =~ s/_//ms;
 
 with 'Perl::Dist::WiX::Role::Asset';
@@ -180,7 +180,7 @@ This class inherits from L<Perl::Dist::WiX::Role::Asset> and shares its API.
 
 =head2 new
 
-TODO: TO BE COMPLETED
+TODO: Document
 
 =head2 install
 
