@@ -9,7 +9,7 @@ use File::Spec::Functions qw( catdir splitpath rel2abs catfile );
 require File::Remove;
 require File::Basename;
 
-our $VERSION = '1.102';
+our $VERSION = '1.102002';
 $VERSION =~ s/_//ms;
 
 with 'Perl::Dist::WiX::Role::Asset';
@@ -248,11 +248,11 @@ Perl::Dist::WiX::Asset::Perl - "Perl core" asset for a Win32 Perl
 
 =head1 DESCRIPTION
 
-TODO
+TODO: Document
 
 =head1 METHODS
 
-TODO
+TODO: Document
 
 This class is a L<Perl::Dist::WiX::Role::Asset> and shares its API.
 
