@@ -10,7 +10,7 @@ use Params::Util qw( _STRING );
 use Digest::CRC qw( crc32_base64 );
 require Perl::Dist::WiX::Exceptions;
 
-our $VERSION = '1.102';
+our $VERSION = '1.102002';
 $VERSION =~ s/_//ms;
 
 extends 'WiX3::XML::Directory';
@@ -211,7 +211,7 @@ Perl::Dist::WiX::Tag::Directory - <Directory> tag that knows how to search its c
 
 	my $ref_tag = Perl::Dist::WiX::Tag::Directory->new(
 		id => 'Perl'
-		# TODO.
+		# TODO: Finish documenting
 	);
 
 	# Parameters can be passed as a hash, or a hashref.
@@ -262,7 +262,7 @@ An undefined value is returned if no object with that ID could be found.
 
 =head2 search_dir
 
-TODO
+TODO: Document
 
 =head2 add_directories_id
 
